pub struct CommentBundle {
pub commentable_meta: Vec<CommentableMeta>,
pub comments: Vec<Comment>,
pub has_more_id: Option<u32>,
pub included_comments: Vec<Comment>,
pub pinned_comments: Option<Vec<Comment>>,
pub sort: CommentSort,
pub top_level_count: Option<u32>,
pub total: Option<u32>,
pub user_follow: bool,
pub user_votes: Vec<u32>,
pub users: Vec<User>,
/* private fields */
}Expand description
Comments and related data.
Fields
commentable_meta: Vec<CommentableMeta>ID of the object the comment is attached to
comments: Vec<Comment>List of comments ordered according to sort
has_more_id: Option<u32>included_comments: Vec<Comment>Related comments; e.g. parent comments and nested replies
pinned_comments: Option<Vec<Comment>>Pinned comments
sort: CommentSortorder of comments
top_level_count: Option<u32>Number of comments at the top level. Not returned for replies.
total: Option<u32>Total number of comments. Not retuned for replies.
user_follow: boolis the current user watching the comment thread?
user_votes: Vec<u32>IDs of the comments in the bundle the current user has upvoted
users: Vec<User>List of users related to the comments
Implementations