Events

Struct Events 

pub struct Events {
    pub events: Vec<Event>,
    pub cursor: Option<String>,
    /* private fields */
}

Fields

events: Vec<Event>cursor: Option<String>

Implementations

Source

impl Events

pub const fn has_more(&self) -> bool

Returns whether there is a next page of events, retrievable via get_next.

pub async fn get_next(&self, osu: &Osu) -> Option<OsuResult<Events>>

If has_more is true, the API can provide the next set of events and this method will request them. Otherwise, this method returns None.