GameMod

Enum GameMod 

#[non_exhaustive]
pub enum GameMod {
Show 142 variants EasyOsu(EasyOsu), NoFailOsu(NoFailOsu), HalfTimeOsu(HalfTimeOsu), DaycoreOsu(DaycoreOsu), HardRockOsu(HardRockOsu), SuddenDeathOsu(SuddenDeathOsu), PerfectOsu(PerfectOsu), DoubleTimeOsu(DoubleTimeOsu), NightcoreOsu(NightcoreOsu), HiddenOsu(HiddenOsu), FlashlightOsu(FlashlightOsu), BlindsOsu(BlindsOsu), StrictTrackingOsu(StrictTrackingOsu), AccuracyChallengeOsu(AccuracyChallengeOsu), TargetPracticeOsu(TargetPracticeOsu), DifficultyAdjustOsu(DifficultyAdjustOsu), ClassicOsu(ClassicOsu), RandomOsu(RandomOsu), MirrorOsu(MirrorOsu), AlternateOsu(AlternateOsu), SingleTapOsu(SingleTapOsu), AutoplayOsu(AutoplayOsu), CinemaOsu(CinemaOsu), RelaxOsu(RelaxOsu), AutopilotOsu(AutopilotOsu), SpunOutOsu(SpunOutOsu), TransformOsu(TransformOsu), WiggleOsu(WiggleOsu), SpinInOsu(SpinInOsu), GrowOsu(GrowOsu), DeflateOsu(DeflateOsu), WindUpOsu(WindUpOsu), WindDownOsu(WindDownOsu), TraceableOsu(TraceableOsu), BarrelRollOsu(BarrelRollOsu), ApproachDifferentOsu(ApproachDifferentOsu), MutedOsu(MutedOsu), NoScopeOsu(NoScopeOsu), MagnetisedOsu(MagnetisedOsu), RepelOsu(RepelOsu), AdaptiveSpeedOsu(AdaptiveSpeedOsu), FreezeFrameOsu(FreezeFrameOsu), BubblesOsu(BubblesOsu), SynesthesiaOsu(SynesthesiaOsu), DepthOsu(DepthOsu), BloomOsu(BloomOsu), TouchDeviceOsu(TouchDeviceOsu), ScoreV2Osu(ScoreV2Osu), UnknownOsu(UnknownMod), EasyTaiko(EasyTaiko), NoFailTaiko(NoFailTaiko), HalfTimeTaiko(HalfTimeTaiko), DaycoreTaiko(DaycoreTaiko), HardRockTaiko(HardRockTaiko), SuddenDeathTaiko(SuddenDeathTaiko), PerfectTaiko(PerfectTaiko), DoubleTimeTaiko(DoubleTimeTaiko), NightcoreTaiko(NightcoreTaiko), HiddenTaiko(HiddenTaiko), FlashlightTaiko(FlashlightTaiko), AccuracyChallengeTaiko(AccuracyChallengeTaiko), RandomTaiko(RandomTaiko), DifficultyAdjustTaiko(DifficultyAdjustTaiko), ClassicTaiko(ClassicTaiko), SwapTaiko(SwapTaiko), SingleTapTaiko(SingleTapTaiko), ConstantSpeedTaiko(ConstantSpeedTaiko), AutoplayTaiko(AutoplayTaiko), CinemaTaiko(CinemaTaiko), RelaxTaiko(RelaxTaiko), WindUpTaiko(WindUpTaiko), WindDownTaiko(WindDownTaiko), MutedTaiko(MutedTaiko), AdaptiveSpeedTaiko(AdaptiveSpeedTaiko), ScoreV2Taiko(ScoreV2Taiko), UnknownTaiko(UnknownMod), EasyCatch(EasyCatch), NoFailCatch(NoFailCatch), HalfTimeCatch(HalfTimeCatch), DaycoreCatch(DaycoreCatch), HardRockCatch(HardRockCatch), SuddenDeathCatch(SuddenDeathCatch), PerfectCatch(PerfectCatch), DoubleTimeCatch(DoubleTimeCatch), NightcoreCatch(NightcoreCatch), HiddenCatch(HiddenCatch), FlashlightCatch(FlashlightCatch), AccuracyChallengeCatch(AccuracyChallengeCatch), DifficultyAdjustCatch(DifficultyAdjustCatch), ClassicCatch(ClassicCatch), MirrorCatch(MirrorCatch), AutoplayCatch(AutoplayCatch), CinemaCatch(CinemaCatch), RelaxCatch(RelaxCatch), WindUpCatch(WindUpCatch), WindDownCatch(WindDownCatch), FloatingFruitsCatch(FloatingFruitsCatch), MutedCatch(MutedCatch), NoScopeCatch(NoScopeCatch), ScoreV2Catch(ScoreV2Catch), UnknownCatch(UnknownMod), EasyMania(EasyMania), NoFailMania(NoFailMania), HalfTimeMania(HalfTimeMania), DaycoreMania(DaycoreMania), NoReleaseMania(NoReleaseMania), HardRockMania(HardRockMania), SuddenDeathMania(SuddenDeathMania), PerfectMania(PerfectMania), DoubleTimeMania(DoubleTimeMania), NightcoreMania(NightcoreMania), FadeInMania(FadeInMania), HiddenMania(HiddenMania), CoverMania(CoverMania), FlashlightMania(FlashlightMania), AccuracyChallengeMania(AccuracyChallengeMania), RandomMania(RandomMania), DualStagesMania(DualStagesMania), MirrorMania(MirrorMania), DifficultyAdjustMania(DifficultyAdjustMania), ClassicMania(ClassicMania), InvertMania(InvertMania), ConstantSpeedMania(ConstantSpeedMania), HoldOffMania(HoldOffMania), OneKeyMania(OneKeyMania), TwoKeysMania(TwoKeysMania), ThreeKeysMania(ThreeKeysMania), FourKeysMania(FourKeysMania), FiveKeysMania(FiveKeysMania), SixKeysMania(SixKeysMania), SevenKeysMania(SevenKeysMania), EightKeysMania(EightKeysMania), NineKeysMania(NineKeysMania), TenKeysMania(TenKeysMania), AutoplayMania(AutoplayMania), CinemaMania(CinemaMania), WindUpMania(WindUpMania), WindDownMania(WindDownMania), MutedMania(MutedMania), AdaptiveSpeedMania(AdaptiveSpeedMania), ScoreV2Mania(ScoreV2Mania), UnknownMania(UnknownMod),
}
A single game mod

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EasyOsu(EasyOsu)



NoFailOsu(NoFailOsu)



HalfTimeOsu(HalfTimeOsu)



DaycoreOsu(DaycoreOsu)



HardRockOsu(HardRockOsu)



SuddenDeathOsu(SuddenDeathOsu)



PerfectOsu(PerfectOsu)



DoubleTimeOsu(DoubleTimeOsu)



NightcoreOsu(NightcoreOsu)



HiddenOsu(HiddenOsu)



FlashlightOsu(FlashlightOsu)



BlindsOsu(BlindsOsu)



StrictTrackingOsu(StrictTrackingOsu)



AccuracyChallengeOsu(AccuracyChallengeOsu)



TargetPracticeOsu(TargetPracticeOsu)



DifficultyAdjustOsu(DifficultyAdjustOsu)



ClassicOsu(ClassicOsu)



RandomOsu(RandomOsu)



MirrorOsu(MirrorOsu)



AlternateOsu(AlternateOsu)



SingleTapOsu(SingleTapOsu)



AutoplayOsu(AutoplayOsu)



CinemaOsu(CinemaOsu)



RelaxOsu(RelaxOsu)



AutopilotOsu(AutopilotOsu)



SpunOutOsu(SpunOutOsu)



TransformOsu(TransformOsu)



WiggleOsu(WiggleOsu)



SpinInOsu(SpinInOsu)



GrowOsu(GrowOsu)



DeflateOsu(DeflateOsu)



WindUpOsu(WindUpOsu)



WindDownOsu(WindDownOsu)



TraceableOsu(TraceableOsu)



BarrelRollOsu(BarrelRollOsu)



ApproachDifferentOsu(ApproachDifferentOsu)



MutedOsu(MutedOsu)



NoScopeOsu(NoScopeOsu)



MagnetisedOsu(MagnetisedOsu)



RepelOsu(RepelOsu)



AdaptiveSpeedOsu(AdaptiveSpeedOsu)



FreezeFrameOsu(FreezeFrameOsu)



BubblesOsu(BubblesOsu)



SynesthesiaOsu(SynesthesiaOsu)



DepthOsu(DepthOsu)



BloomOsu(BloomOsu)



TouchDeviceOsu(TouchDeviceOsu)



ScoreV2Osu(ScoreV2Osu)



UnknownOsu(UnknownMod)



EasyTaiko(EasyTaiko)



NoFailTaiko(NoFailTaiko)



HalfTimeTaiko(HalfTimeTaiko)



DaycoreTaiko(DaycoreTaiko)



HardRockTaiko(HardRockTaiko)



SuddenDeathTaiko(SuddenDeathTaiko)



PerfectTaiko(PerfectTaiko)



DoubleTimeTaiko(DoubleTimeTaiko)



NightcoreTaiko(NightcoreTaiko)



HiddenTaiko(HiddenTaiko)



FlashlightTaiko(FlashlightTaiko)



AccuracyChallengeTaiko(AccuracyChallengeTaiko)



RandomTaiko(RandomTaiko)



DifficultyAdjustTaiko(DifficultyAdjustTaiko)



ClassicTaiko(ClassicTaiko)



SwapTaiko(SwapTaiko)



SingleTapTaiko(SingleTapTaiko)



ConstantSpeedTaiko(ConstantSpeedTaiko)



AutoplayTaiko(AutoplayTaiko)



CinemaTaiko(CinemaTaiko)



RelaxTaiko(RelaxTaiko)



WindUpTaiko(WindUpTaiko)



WindDownTaiko(WindDownTaiko)



MutedTaiko(MutedTaiko)



AdaptiveSpeedTaiko(AdaptiveSpeedTaiko)



ScoreV2Taiko(ScoreV2Taiko)



UnknownTaiko(UnknownMod)



EasyCatch(EasyCatch)



NoFailCatch(NoFailCatch)



HalfTimeCatch(HalfTimeCatch)



DaycoreCatch(DaycoreCatch)



HardRockCatch(HardRockCatch)



SuddenDeathCatch(SuddenDeathCatch)



PerfectCatch(PerfectCatch)



DoubleTimeCatch(DoubleTimeCatch)



NightcoreCatch(NightcoreCatch)



HiddenCatch(HiddenCatch)



FlashlightCatch(FlashlightCatch)



AccuracyChallengeCatch(AccuracyChallengeCatch)



DifficultyAdjustCatch(DifficultyAdjustCatch)



ClassicCatch(ClassicCatch)



MirrorCatch(MirrorCatch)



AutoplayCatch(AutoplayCatch)



CinemaCatch(CinemaCatch)



RelaxCatch(RelaxCatch)



WindUpCatch(WindUpCatch)



WindDownCatch(WindDownCatch)



FloatingFruitsCatch(FloatingFruitsCatch)



MutedCatch(MutedCatch)



NoScopeCatch(NoScopeCatch)



ScoreV2Catch(ScoreV2Catch)



UnknownCatch(UnknownMod)



EasyMania(EasyMania)



NoFailMania(NoFailMania)



HalfTimeMania(HalfTimeMania)



DaycoreMania(DaycoreMania)



NoReleaseMania(NoReleaseMania)



HardRockMania(HardRockMania)



SuddenDeathMania(SuddenDeathMania)



PerfectMania(PerfectMania)



DoubleTimeMania(DoubleTimeMania)



NightcoreMania(NightcoreMania)



FadeInMania(FadeInMania)



HiddenMania(HiddenMania)



CoverMania(CoverMania)



FlashlightMania(FlashlightMania)



AccuracyChallengeMania(AccuracyChallengeMania)



RandomMania(RandomMania)



DualStagesMania(DualStagesMania)



MirrorMania(MirrorMania)



DifficultyAdjustMania(DifficultyAdjustMania)



ClassicMania(ClassicMania)



InvertMania(InvertMania)



ConstantSpeedMania(ConstantSpeedMania)



HoldOffMania(HoldOffMania)



OneKeyMania(OneKeyMania)



TwoKeysMania(TwoKeysMania)



ThreeKeysMania(ThreeKeysMania)



FourKeysMania(FourKeysMania)



FiveKeysMania(FiveKeysMania)



SixKeysMania(SixKeysMania)



SevenKeysMania(SevenKeysMania)



EightKeysMania(EightKeysMania)



NineKeysMania(NineKeysMania)



TenKeysMania(TenKeysMania)



AutoplayMania(AutoplayMania)



CinemaMania(CinemaMania)



WindUpMania(WindUpMania)



WindDownMania(WindDownMania)



MutedMania(MutedMania)



AdaptiveSpeedMania(AdaptiveSpeedMania)



ScoreV2Mania(ScoreV2Mania)



UnknownMania(UnknownMod)

Implementations

Source

impl GameMod

pub const fn clock_rate(&self) -> Option<f64>

The clock rate of the GameMod.

Returns None if there is no single clock rate.

Source

impl GameMod

pub fn new(acronym: &str, mode: GameMode) -> GameMod

Create a new GameMod

pub const fn acronym(&self) -> Acronym

The acronym of this GameMod

pub fn incompatible_mods(&self) -> Box<[Acronym]>

List of Acronym for mods that are incompatible with this GameMod

pub const fn description(&self) -> &'static str

The description of this GameMod

pub const fn kind(&self) -> GameModKind

The GameModKind of this GameMod

pub const fn bits(&self) -> Option<u32>

Optional bit value of this GameMod

See https://github.com/ppy/osu-api/wiki#mods

pub const fn mode(&self) -> GameMode

The GameMode of a GameMod

pub const fn intermode(&self) -> GameModIntermode

The kind of a GameMod when ignoring the mode