pub struct ApproachDifferentOsu {
pub scale: Option<f64>,
pub style: Option<String>,
}Expand description
Never trust the approach circles…
Fields
scale: Option<f64>Change the initial size of the approach circle, relative to hit circles.
style: Option<String>Change the animation style of the approach circles.
Implementations
Sourceimpl ApproachDifferentOsu
impl ApproachDifferentOsu
Sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of ApproachDifferentOsu
Sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with ApproachDifferentOsu
Sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of ApproachDifferentOsu
Sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of ApproachDifferentOsu