pub struct DifficultyAdjustCatch {
pub circle_size: Option<f64>,
pub approach_rate: Option<f64>,
pub hard_rock_offsets: Option<bool>,
pub drain_rate: Option<f64>,
pub overall_difficulty: Option<f64>,
pub extended_limits: Option<bool>,
}Expand description
Override a beatmap’s difficulty settings.
Fields
circle_size: Option<f64>Override a beatmap’s set CS.
approach_rate: Option<f64>Override a beatmap’s set AR.
hard_rock_offsets: Option<bool>Adjust the patterns as if Hard Rock is enabled.
drain_rate: Option<f64>Override a beatmap’s set HP.
overall_difficulty: Option<f64>Override a beatmap’s set OD.
extended_limits: Option<bool>Adjust difficulty beyond sane limits.
Implementations
Sourceimpl DifficultyAdjustCatch
impl DifficultyAdjustCatch
Sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of DifficultyAdjustCatch
Sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with DifficultyAdjustCatch
Sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of DifficultyAdjustCatch
Sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of DifficultyAdjustCatch