pub struct TargetPracticeOsu {
pub seed: Option<f64>,
pub metronome: Option<bool>,
}Expand description
Practice keeping up with the beat of the song.
Fields
seed: Option<f64>Use a custom seed instead of a random one
metronome: Option<bool>Whether a metronome beat should play in the background
Implementations
Sourceimpl TargetPracticeOsu
impl TargetPracticeOsu
Sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of TargetPracticeOsu
Sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with TargetPracticeOsu
Sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of TargetPracticeOsu
Sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of TargetPracticeOsu
Sourcepub const fn bits() -> u32
pub const fn bits() -> u32
Bit value of TargetPracticeOsu