pub struct UserExtended {Show 68 fields
pub avatar_url: String,
pub comments_count: usize,
pub country: String,
pub country_code: CountryCode,
pub cover: UserCover,
pub default_group: String,
pub discord: Option<String>,
pub has_supported: bool,
pub interests: Option<String>,
pub is_active: bool,
pub is_bot: bool,
pub is_deleted: bool,
pub is_online: bool,
pub is_supporter: bool,
pub join_date: OffsetDateTime,
pub kudosu: UserKudosu,
pub last_visit: Option<OffsetDateTime>,
pub location: Option<String>,
pub max_blocks: u32,
pub max_friends: u32,
pub mode: GameMode,
pub occupation: Option<String>,
pub playstyle: Option<Vec<Playstyle>>,
pub pm_friends_only: bool,
pub forum_post_count: u32,
pub profile_color: Option<String>,
pub profile_order: Vec<ProfilePage>,
pub team: Option<Team>,
pub title: Option<String>,
pub title_url: Option<String>,
pub twitter: Option<String>,
pub user_id: u32,
pub username: Username,
pub website: Option<String>,
pub account_history: Option<Vec<AccountHistory>>,
pub badges: Option<Vec<Badge>>,
pub beatmap_playcounts_count: Option<u32>,
pub daily_challenge_stats: DailyChallengeUserStatistics,
pub favourite_mapset_count: Option<u32>,
pub follower_count: Option<u32>,
pub graveyard_mapset_count: Option<u32>,
pub groups: Option<Vec<Group>>,
pub guest_mapset_count: Option<u32>,
pub highest_rank: Option<UserHighestRank>,
pub is_admin: Option<bool>,
pub is_bng: Option<bool>,
pub is_full_bn: Option<bool>,
pub is_gmt: Option<bool>,
pub is_limited_bn: Option<bool>,
pub is_moderator: Option<bool>,
pub is_nat: Option<bool>,
pub is_silenced: Option<bool>,
pub loved_mapset_count: Option<u32>,
pub mapping_follower_count: Option<u32>,
pub monthly_playcounts: Option<Vec<MonthlyCount>>,
pub page: Option<UserPage>,
pub previous_usernames: Option<Vec<Username>>,
pub rank_history: Option<Vec<u32>>,
pub ranked_mapset_count: Option<u32>,
pub replays_watched_counts: Option<Vec<MonthlyCount>>,
pub scores_best_count: Option<u32>,
pub scores_first_count: Option<u32>,
pub scores_recent_count: Option<u32>,
pub statistics: Option<UserStatistics>,
pub statistics_modes: UserStatisticsModes,
pub support_level: Option<u8>,
pub pending_mapset_count: Option<u32>,
pub medals: Option<Vec<MedalCompact>>,
}Expand description
Represents a User. Extends User object with additional attributes.
Fields
avatar_url: Stringurl of user’s avatar
comments_count: usizenumber of forum comments
country: Stringcountry of the user
country_code: CountryCodetwo-letter code representing user’s country
cover: UserCoverurls for the profile cover
default_group: StringIdentifier of the default Group the user belongs to.
discord: Option<String>discord tag, None if not specified by the user
has_supported: boolwhether or not ever being a supporter in the past
interests: Option<String>interests, None if not specified by the user
is_active: boolhas this account been active in the last x months?
is_bot: boolis this a bot account?
is_deleted: boolhas this user been deleted?
is_online: boolis the user currently online? (either on lazer or the new website)
is_supporter: booldoes this user have supporter?
join_date: OffsetDateTimedate of account creation
kudosu: UserKudosucurrent kudosu of the user
last_visit: Option<OffsetDateTime>last access time. None if the user hides online presence
location: Option<String>location of the user, None if disabled by the user
max_blocks: u32maximum number of users allowed to be blocked
max_friends: u32maximum number of friends allowed to be added
mode: GameModemode for this struct
occupation: Option<String>occupation, None if not specified by the user
playstyle: Option<Vec<Playstyle>>Device choices of the user
pm_friends_only: boolwhether or not the user allows PM from other than friends
forum_post_count: u32number of forum posts
profile_color: Option<String>colour of username/profile highlight, hex code (e.g. "#333333")
profile_order: Vec<ProfilePage>ordered list of sections in user profile page
team: Option<Team>title: Option<String>user-specific title
title_url: Option<String>URL to the user title
twitter: Option<String>twitter handle, None if not specified by the user
user_id: u32unique identifier for user
username: Usernameuser’s display name
website: Option<String>website, None if not specified by the user
account_history: Option<Vec<AccountHistory>>badges: Option<Vec<Badge>>beatmap_playcounts_count: Option<u32>daily_challenge_stats: DailyChallengeUserStatisticsfavourite_mapset_count: Option<u32>follower_count: Option<u32>graveyard_mapset_count: Option<u32>groups: Option<Vec<Group>>guest_mapset_count: Option<u32>highest_rank: Option<UserHighestRank>is_admin: Option<bool>is_bng: Option<bool>is_full_bn: Option<bool>is_gmt: Option<bool>is_limited_bn: Option<bool>is_moderator: Option<bool>is_nat: Option<bool>is_silenced: Option<bool>loved_mapset_count: Option<u32>mapping_follower_count: Option<u32>monthly_playcounts: Option<Vec<MonthlyCount>>page: Option<UserPage>previous_usernames: Option<Vec<Username>>rank_history: Option<Vec<u32>>ranked_mapset_count: Option<u32>Counts both ranked and approved mapsets
replays_watched_counts: Option<Vec<MonthlyCount>>scores_best_count: Option<u32>scores_first_count: Option<u32>scores_recent_count: Option<u32>statistics: Option<UserStatistics>statistics_modes: UserStatisticsModessupport_level: Option<u8>pending_mapset_count: Option<u32>medals: Option<Vec<MedalCompact>>Trait Implementations
Sourceimpl Clone for UserExtended
impl Clone for UserExtended
Sourcefn clone(&self) -> UserExtended
fn clone(&self) -> UserExtended
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more