pub struct RandomMania {
pub seed: Option<f64>,
}Expand description
Shuffle around the keys!
Fields
seed: Option<f64>Use a custom seed instead of a random one
Implementations
Sourceimpl RandomMania
impl RandomMania
Sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of RandomMania
Sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with RandomMania
Sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of RandomMania
Sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of RandomMania
Sourcepub const fn bits() -> u32
pub const fn bits() -> u32
Bit value of RandomMania