pub struct GetBeatmapScores<'a> { /* private fields */ }Expand description
Get top scores of a beatmap as BeatmapScores.
Implementations
Sourceimpl<'a> GetBeatmapScores<'a>
impl<'a> GetBeatmapScores<'a>
Sourcepub fn mods<M>(self, mods: M) -> Selfwhere
GameModsIntermode: From<M>,
pub fn mods<M>(self, mods: M) -> Selfwhere
GameModsIntermode: From<M>,
Specify the mods of the scores
Sourcepub const fn country(self) -> Self
pub const fn country(self) -> Self
Specify that the national leaderboard should be requested.
Note that you must be authenticated through OAuth and have osu!supporter to use this.
pub const fn limit(self, limit: u32) -> Self
Sourcepub const fn legacy_only(self, legacy_only: bool) -> Self
pub const fn legacy_only(self, legacy_only: bool) -> Self
Whether or not to exclude lazer scores.
Sourcepub const fn legacy_scores(self, legacy_scores: bool) -> Self
pub const fn legacy_scores(self, legacy_scores: bool) -> Self
Specify whether the scores should contain legacy data or not.
Legacy data consists of a different grade calculation, less populated statistics, legacy mods, and a different score kind.