pub struct GetBeatmapUserScore<'a> { /* private fields */ }Expand description
Get BeatmapUserScore of a user on a beatmap.
Implementations
Sourceimpl<'a> GetBeatmapUserScore<'a>
impl<'a> GetBeatmapUserScore<'a>
Sourcepub fn mods<M>(self, mods: M) -> Selfwhere
GameModsIntermode: From<M>,
pub fn mods<M>(self, mods: M) -> Selfwhere
GameModsIntermode: From<M>,
Specify the mods
Sourcepub const fn legacy_only(self, legacy_only: bool) -> Self
pub const fn legacy_only(self, legacy_only: bool) -> Self
Whether or not to exclude lazer scores.
Sourcepub const fn legacy_scores(self, legacy_scores: bool) -> Self
pub const fn legacy_scores(self, legacy_scores: bool) -> Self
Specify whether the score should contain legacy data or not.
Legacy data consists of a different grade calculation, less populated statistics, legacy mods, and a different score kind.