pub struct GetComments<'a> { /* private fields */ }Expand description
Get a list of comments and their replies up to two levels deep in form of a
CommentBundle.
Implementations
Sourceimpl<'a> GetComments<'a>
impl<'a> GetComments<'a>
Sourcepub const fn parent(self, parent_id: u32) -> Self
pub const fn parent(self, parent_id: u32) -> Self
Limit to comments which are reply to the specified id. Specify 0 to get top level comments
Sourcepub const fn commentable_id(self, commentable_id: u32) -> Self
pub const fn commentable_id(self, commentable_id: u32) -> Self
The id of the resource to get comments for
Sourcepub fn commentable_type(self, commentable_type: impl Into<String>) -> Self
pub fn commentable_type(self, commentable_type: impl Into<String>) -> Self
The type of resource to get comments for