GetFriends

Struct GetFriends 

pub struct GetFriends<'a> { /* private fields */ }
Get all friends of the authenticated user as a vec of User.

Note that the client has to be initialized with the FriendsRead scope through the OAuth process in order for this endpoint to not return an error.

See OsuBuilder::with_authorization.