pub struct GetOwnData<'a> { /* private fields */ }Expand description
Get the UserExtended of the authenticated user.
Note that the client has to be initialized with the Identify scope
through the OAuth process in order for this endpoint to not return an error.
Implementations