GetUserScores

Struct GetUserScores 

pub struct GetUserScores<'a> { /* private fields */ }
Get a vec of Scores of a user.

If no score type is specified by either best, firsts, or recent, it defaults to best.

Implementations

Source

impl<'a> GetUserScores<'a>

pub const fn limit(self, limit: usize) -> Self

The API provides at most 100 results per requests.

pub const fn offset(self, offset: usize) -> Self

Set an offset for the requested elements e.g. skip the first offset amount in the list

pub const fn mode(self, mode: GameMode) -> Self

Specify the mode of the scores

pub const fn include_fails(self, include_fails: bool) -> Self

Specify whether failed scores can be included.

Only relevant for recent

pub const fn best(self) -> Self

Get top scores of a user

pub const fn firsts(self) -> Self

Get global #1 scores of a user.

pub const fn pinned(self) -> Self

Get the pinned scores of a user.

pub const fn recent(self) -> Self

Get recent scores of a user.

pub const fn legacy_only(self, legacy_only: bool) -> Self

Whether or not to exclude lazer scores.

pub const fn legacy_scores(self, legacy_scores: bool) -> Self

Specify whether the scores should contain legacy data or not.

Legacy data consists of a different grade calculation, less populated statistics, legacy mods, and a different score kind.