pub struct OsuFuture<T: OsuFutureData> { /* private fields */ }Expand description
Awaitable Future to fetch and process data from an endpoint.
When fetching from user endpoints by name instead of id, the OsuFuture
might first perform a request to fetch the user itself, and then perform
the actual request by using the fetched user id. If the cache feature
is enabled, fetched user data will be stored to potentially prevent
intermediate user requests later on.