pub struct ForumPosts {
pub cursor: Option<String>,
pub posts: Vec<ForumPost>,
pub search: ForumPostsSearch,
pub topic: ForumTopic,
}Fields
cursor: Option<String>posts: Vec<ForumPost>search: ForumPostsSearchtopic: ForumTopicImplementations
Sourceimpl ForumPosts
impl ForumPosts
Sourcepub const fn has_more(&self) -> bool
pub const fn has_more(&self) -> bool
Checks whether the cursor field is Some which in turn
can be used to retrieve the next set of posts.
The next set can then be retrieved by providing this cursor to
GetForumPosts::cursor.
Be sure all other parameters stay the same.