pub struct ScoreStatistics {Show 17 fields
pub miss: u32,
pub meh: u32,
pub ok: u32,
pub good: u32,
pub great: u32,
pub perfect: u32,
pub large_tick_hit: u32,
pub large_tick_miss: u32,
pub small_tick_hit: u32,
pub small_tick_miss: u32,
pub ignore_hit: u32,
pub ignore_miss: u32,
pub large_bonus: u32,
pub small_bonus: u32,
pub slider_tail_hit: u32,
pub combo_break: u32,
pub legacy_combo_increase: u32,
}Fields
miss: u32meh: u32ok: u32good: u32great: u32perfect: u32large_tick_hit: u32large_tick_miss: u32small_tick_hit: u32small_tick_miss: u32ignore_hit: u32ignore_miss: u32large_bonus: u32small_bonus: u32slider_tail_hit: u32combo_break: u32legacy_combo_increase: u32Implementations
Sourceimpl ScoreStatistics
impl ScoreStatistics
Sourcepub const fn total_hits(&self, mode: GameMode) -> u32
pub const fn total_hits(&self, mode: GameMode) -> u32
Count all hitobjects of the score i.e. for GameMode::Osu the amount 300s, 100s, 50s, and misses.
Note: Includes tiny droplet (misses) for GameMode::Catch.
Sourcepub fn accuracy(&self, mode: GameMode, max_statistics: &ScoreStatistics) -> f32
pub fn accuracy(&self, mode: GameMode, max_statistics: &ScoreStatistics) -> f32
Calculate the accuracy rounded to two decimal points i.e. 0 <= accuracy <= 100
Sourcepub fn legacy_accuracy(&self, mode: GameMode) -> f32
pub fn legacy_accuracy(&self, mode: GameMode) -> f32
Calculate the accuracy rounded to two decimal points i.e. 0 <= accuracy <= 100.
Slider hits and such will not be considered.
Sourcepub const fn as_legacy(&self, mode: GameMode) -> LegacyScoreStatistics
pub const fn as_legacy(&self, mode: GameMode) -> LegacyScoreStatistics
Turn ScoreStatistics into LegacyScoreStatistics