GetBeatmapUserScore

Struct GetBeatmapUserScore 

pub struct GetBeatmapUserScore<'a> { /* private fields */ }
Get BeatmapUserScore of a user on a beatmap.

Implementations

Source

impl<'a> GetBeatmapUserScore<'a>

pub const fn mode(self, mode: GameMode) -> Self

Specify the mode

pub fn mods<M>(self, mods: M) -> Self

Specify the mods

pub const fn legacy_only(self, legacy_only: bool) -> Self

Whether or not to exclude lazer scores.

pub const fn legacy_scores(self, legacy_scores: bool) -> Self

Specify whether the score should contain legacy data or not.

Legacy data consists of a different grade calculation, less populated statistics, legacy mods, and a different score kind.