GetOwnData

Struct GetOwnData 

pub struct GetOwnData<'a> { /* private fields */ }
Get the UserExtended of the authenticated user.

Note that the client has to be initialized with the Identify scope through the OAuth process in order for this endpoint to not return an error.

See OsuBuilder::with_authorization.

Implementations

Source

impl<'a> GetOwnData<'a>

pub const fn mode(self, mode: GameMode) -> Self

Specify the mode for which the user data should be retrieved