pub struct GetUserScores<'a> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a> GetUserScores<'a>
impl<'a> GetUserScores<'a>
Sourcepub const fn limit(self, limit: usize) -> Self
pub const fn limit(self, limit: usize) -> Self
The API provides at most 100 results per requests.
Sourcepub const fn offset(self, offset: usize) -> Self
pub const fn offset(self, offset: usize) -> Self
Set an offset for the requested elements
e.g. skip the first offset amount in the list
Sourcepub const fn include_fails(self, include_fails: bool) -> Self
pub const fn include_fails(self, include_fails: bool) -> Self
Specify whether failed scores can be included.
Only relevant for recent
Sourcepub const fn legacy_only(self, legacy_only: bool) -> Self
pub const fn legacy_only(self, legacy_only: bool) -> Self
Whether or not to exclude lazer scores.
Sourcepub const fn legacy_scores(self, legacy_scores: bool) -> Self
pub const fn legacy_scores(self, legacy_scores: bool) -> Self
Specify whether the scores should contain legacy data or not.
Legacy data consists of a different grade calculation, less populated statistics, legacy mods, and a different score kind.